@@ -9,7 +9,7 @@ from PyQt4.QtCore import Qt
 from PyQt4 import QtCore, QtGui
 
 class Server(QtCore.QObject):
-	def __init__(self, namei,  serverI,  log,  pwd, portc,  parent=None):
+	def __init__(self, namei,  serverI,  log,  pwd, portc, conntypec,   parent=None):
 		QObject.__init__(self, parent)
 		
 		self.name = namei
@@ -17,3 +17,5 @@ class Server(QtCore.QObject):
 		self.login = log
 		self.password = pwd
 		self.port = portc
+		#Either FTP (default) or SFTP/SCP
+		self.connection = conntypec
