@@ -70,6 +70,8 @@ class BookmarkList(QMainWindow, Ui_MainWindow):
 			if ret == 0:
 				if self.xmlBookmark.deleteServer(servername):
 					self.readList()
+					if 	self.parentWindow.parentWindow.m_label_remote.text()=="Bookmarks:":
+						self.parentWindow.parentWindow.readBookmarkList()
 		elif action == editAction:
 			self.bookmarkEdit.editServer(servername)
 			self.bookmarkEdit.show()
