@@ -40,6 +40,10 @@ class OpenServer(QMainWindow, Ui_MainWindow):
 		self.m_le_server.setText(server.server)
 		self.m_le_user.setText(server.login)
 		self.m_le_port.setText(server.port)
+		if server.connection == "FTP":
+			self.m_cb_connection_type.setCurrentIndex(0)
+		else:
+			self.m_cb_connection_type.setCurrentIndex(1)
     
     @pyqtSignature("")
     def on_m_bu_open_bookmarks_clicked(self):
@@ -51,7 +55,12 @@ class OpenServer(QMainWindow, Ui_MainWindow):
     
     @pyqtSignature("")
     def on_m_bu_connect_clicked(self):
-        self.parentWindow.connectToServer(self.m_le_server.text(), self.m_le_user.text(),  self.m_le_password.text(),  self.m_le_port.text())
+        self.parentWindow.connectToServer(self.m_le_server.text(), self.m_le_user.text(),  self.m_le_password.text(),  self.m_le_port.text(),  self.m_cb_connection_type.currentText())
         self.hide()
-		
-
+    
+    @pyqtSignature("QString")
+    def on_m_cb_connection_type_currentIndexChanged(self, p0):
+        if p0 == "FTP" and self.m_le_port.text()=="22":
+			self.m_le_port.setText("21")
+        elif p0 != "FTP" and self.m_le_port.text() == "21":
+			self.m_le_port.setText("22")
